@@ -161,7 +161,7 @@ class PrimaryDeviceBase(abc.ABC):
 
   @abc.abstractmethod
   def make_device_ready(
-      self, setting: data_types.MAKE_DEVICE_READY_SETTING = "on") -> None:
+      self, setting: data_types.MakeDeviceReadySettingStr = "on") -> None:
     """Checks device readiness and attempts recovery if allowed.
 
     If setting is 'off': does nothing.
@@ -237,6 +237,18 @@ class PrimaryDeviceBase(abc.ABC):
         include_return_code is True.
     """
 
+  @abc.abstractmethod
+  def wait_until_connected(self, timeout: Optional[int] = None) -> None:
+    """Wait until the device is connected to the host.
+
+    Args:
+        timeout: Max time to wait for the device to be reachable from the host.
+
+    Raises:
+        DeviceNotConnectedError: device did not become reachable from the host
+            before the timeout was exceeded.
+    """
+
   @abc.abstractmethod
   def wait_for_bootup_complete(self, timeout=None):
     """Wait until the device finishes booting up and is ready for testing.
