@@ -31,5 +31,5 @@ class SpeakerBase(endpoint_base.EndpointBase, metaclass=abc.ABCMeta):
 
   @property
   @abc.abstractmethod
-  def level(self) -> level_control_base.LevelControlClusterBase:
+  def level_control(self) -> level_control_base.LevelControlClusterBase:
     """Required cluster: ZCL level cluster."""
