@@ -16,7 +16,9 @@
 import inspect
 
 ANDROID_NAMES = ("Android", "Pixel")
-CAMBRIONIX_NAMES = ("FT230X Basic UART", "PS15-USB3", "SuperSync15")
+CAMBRIONIX_NAMES_USB2 = ("FT230X Basic UART",)
+CAMBRIONIX_NAMES_USB3 = ("PS15-USB3", "SuperSync15")
+CAMBRIONIX_NAMES = CAMBRIONIX_NAMES_USB2 + CAMBRIONIX_NAMES_USB3
 CAMBRIONIX_VENDOR_PRODUCT_ID = ("0403/6015", "2cd9/0021")
 
 CAMBRIONIX_PORT_MAP = {
